@@ -1,4 +1,6 @@
 from .message import message
 from .chatbot import chatbot
 from .return_data import output
-from .discord import discord_trainer
\ No newline at end of file
+from .moodanalyzer import FindMood
+from .discord import discord_trainer
+from .googlechat import googlechat_trainer
\ No newline at end of file
