@@ -1,6 +1,7 @@
 class output:
-    def __init__(self, input, output, confidence, delta):
+    def __init__(self, input, output, confidence, delta, emotion):
         self.content = output
         self.match = input
         self.confidence = confidence
-        self.time = delta
\ No newline at end of file
+        self.time = delta
+        self.emotion = emotion
\ No newline at end of file
